Crate axone_logic_bindings

Crate axone_logic_bindings 

Modules

error
testing

Structs

Answer
AskResponse
Result
Substitution

Enums

LogicCustomQuery
TermValue
Represents a Prolog response term element which can be a tuple, an array or a string value.