Crate axone_logic_bindings
axone_
logic_
bindings
7.0.0
All Items
Crate Items
Modules
Structs
Enums
Crate
axone_
logic_
bindings
Modules

error
testing
Structs

Answer
AskResponse
Result
Substitution
Enums

Logic
Custom
Query
Term
Value
Represents a Prolog response term element which can be a tuple, an array or a string value.